@@ -121,8 +121,8 @@ class Command(BaseCommand):
             # DEV: This is the correct code once this project is on PyPI.
             #   Also, once this is updated, integration test will need to be updated.
             #   (Substitution for dev branch install address.)
-            # self._add_req_txt_pkg('django-simple-deploy')
-            self._add_req_txt_pkg('git+git://github.com/ehmatthes/django-simple-deploy')
+            self._add_req_txt_pkg('django-simple-deploy')
+            # self._add_req_txt_pkg('git+git://github.com/ehmatthes/django-simple-deploy')
 
     def _generate_procfile(self):
         """Create Procfile, if none present."""
